{-------------------------------------------------------------------------------

The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either expressed or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is: InfoStrings.pas, released 2002-01-05.

The Initial Developer of the Original Code is David Polberger <dpol@swipnet.se>
Portions created by David Polberger are Copyright (C) 2002 David Polberger.
All Rights Reserved.

Contributor(s): Ralf Junker <delphi@zeitungsjunge.de>

You may retrieve the latest version of this file at The Delphi Inspiration
home page, located at http://www.zeitungsjunge.de/delphi/

-------------------------------------------------------------------------------}

unit InfoStrings;

interface

const
  NmrOfScreens = 14;
  Headings: array[0..NmrOfScreens - 1] of AnsiString =
  ('Introduction',
    'Origins',
    'What''s New',
    'Unicode Examples I',
    'Unicode Examples II',
    'Formatting Text',
    'Supported Tags',
    'Color Names A - L',
    'Color Names L - Y',
    'Handling Links',
    'Dynamic Tags',
    'Play!',
    'Source Code',
    'Read More');

  HEAD_COLOR = '#00529C';
  ALT_COLOR = '#00203E';

  COLOR_INTRO =
    '<P>' +
    'This is a list of supported color names (case-insensitive). ' +
    'Hexadecimal color values (prefixed by a hash mark ''#'') are also supported: ' +
    '<FONT color=#FF0000>#FF0000</FONT> <FONT color=#00FF00>#00FF00</FONT> ' +
    '<FONT color=#0000FF>#0000FF</FONT> <FONT color=#FF8800>#FF800</FONT>.';

  COLOR_OUTRO =
    '<P>' +
    '<U>Please note:</U> Some colors are not clearly visible against the white background.';

  Info: array[0..NmrOfScreens - 1] of AnsiString = (

    // Introduction
    '<FONT color=' + HEAD_COLOR + '><B>  Introduction</B></FONT>' +
    '<P>' +
    'Welcome to <B>TDIHtmlLabel</B>! Have you ever wanted to include ' +
    'formatted text and links that flow with the rest of the text in your ' +
    'applications? TDIHtmlLabel is a fast, light-weight replacement for ' +
    'Delphi''s TLabel, that handles all this. In fact, the text you''re ' +
    'reading right now, is displayed by the TDIHtmlLabel.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>TDIHtmlLabel is licensed under the ' +
    '<A href=http://www.mozilla.org/MPL/MPL-1.1.html>Mozilla Plublic License ' +
    '(MPL)</A>, which basically means that if you alter the component ' +
    'and distribute an application incorporating it, you must make your changes ' +
    'to the component public. Note, though, that this doesn''t affect your ' +
    'application. Thus, you can safely use TDIHtmlLabel in applications ' +
    'whose source code you want to remain private.</FONT>' +
    '<P>' +
    'Have you seen the source code of a HTML document? This component uses ' +
    'the same technique to format text. <A href=Next>Read on</A> to find out ' +
    'more!',

    // Origins
    '<FONT color=' + HEAD_COLOR + '><B>Origins</B></FONT>' +
    '<P>' +
    '<B>TDIHtmlLabel</B> originates from <I>TJvLinkLabel</I>. TJvLinkLabel was ' +
    'written by <I>David Polberger</I>, but he has withdrawn from its active ' +
    'development and has donated his code to the ' +
    '<A href="http://jvcl.sourceforge.net">JEDI VCL</A>, <I>JVCL</I> in short.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>To get hold of the original files, you need to download the JEDI VCL. ' +
    'The TJvLinkLabel files are located in the Source sub-folder and do all ' +
    'start which with "JvLinkLabel...".</FONT>' +
    '<P>' +
    'To read about the improvements of TDIHtmlLabel compared to the original ' +
    'TJvLinkLabel, <A href=Next>click here</A>.',

    // What's New
    '<FONT color=' + HEAD_COLOR + '><B>What''s New</B></FONT>' +
    '<P>' +
    '<B>Unicode Support</B>, the main new feature of TDIHtmlLabel, has become ' +
    'possible by applying <A href=http://www.zeitungsjunge.de/delphi/>' +
    'DIHtmlParser</A> as the underlying HTML parsing engine. Therefore ' +
    'TDIHtmlLabel is able to display characters from different languages ' +
    'right next to each other even on Win95 &ndash; provided the font applied supports ' +
    'the used characters. DIHtmlLabel reads Unicode by converting ' +
    'all common Html entities, both named and numeric, to Unicode WideStrings internally.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '><I>&amp;alpha;</I>&nbsp;=&nbsp;&alpha; &ndash; <I>&amp;beta;</I>&nbsp;=&nbsp;&beta; &ndash; <I>&amp;gamma;</I>&nbsp;=&nbsp;&gamma;' +
    '<BR>' +
    '<I>&amp;#65;</I>&nbsp;=&nbsp;A &ndash; <I>&amp;#66;</I>&nbsp;=&nbsp;&#66; &ndash; <I>&amp;#67;</I>&nbsp;=&nbsp;&#67;</FONT>' +
    '<P>' +
    'TDIHtmlLabel reads all Html data assigned to its <I>Caption</I> property ' +
    'as Latin1. Additional character sets can easily be added if there is demand for it.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '><B>Attribute Values</B> for the <B>&lt;A href=MyValue></B> and <B>&lt;DYNAMIC id=MyValue></B> ' +
    'tags, which are passed to the <I>OnLinkClick</I> and the <I>OnInitDynamicNode</I> events.</FONT>' +
    '<P>' +
    'Many <B>internal optimizations</B> which boost performance and decrease memory requirements.',

    // Unicode Examples I
    '<FONT color=' + HEAD_COLOR + '><B>Unicode Examples I</B></FONT>' +
    '<P>' +
    '<B>Esperanto:</B> "La&#x16D; Ludoviko Zamenhof bongustas fre&#x15D;a &#x109;e&#x125;a man&#x11D;a&#x135;o kun spicoj."' +
    '<P><FONT color=' + ALT_COLOR + '><B>La Angla:</B> "The quick brown fox jumps over the lazy dog."</FONT>' +
    '<P><B>La Estona:</B> "Ma v&otilde;in klaasi s&uuml;&uuml;a, see ei tee mulle midagi."' +
    '<P><FONT color=' + ALT_COLOR + '><B>La Finna:</B> "Pystyn sy&ouml;m&auml;&auml;n lasia. Se ei koske yht&auml;&auml;n."</FONT>' +
    '<P><B>La Franca:</B> "Le c&oelig;ur d&eacute;&ccedil;u mais l'' &acirc; me plut&ocirc; t na&iuml; ve, Lou&yuml; s r&ecirc; va de crapa&uuml; ter en cano&euml; au del&agrave; des &icirc; les, pr&egrave; s du m&auml; lstr&ouml; m o&ugrave; br&ucirc; ' + 'lent les nov&aelig;."' +
    '<P><FONT color=' + ALT_COLOR + '><B>La Germana:</B> "Falsches &Uuml;ben von Xylophonmusik qu&auml;lt jeden gr&ouml;&szlig;eren Zwerg."</FONT>' +
    '<P><B>La Greka:</B> "&Mu;&pi;&omicron;&rho;&#x3CE; &nu;&alpha; &phi;&#x3AC;&omega; &sigma;&pi;&alpha;&sigma;&mu;&#x3AD;&nu;&alpha; &gamma;&upsilon;&alpha;&lambda;&iota;&#x3AC; &chi;&omega;&rho;&#x3AF;&sigmaf; &nu;&alpha; &pi;&#x3AC;&theta;&omega; ' + '&tau;&#x3AF;&pi;&omicron;&tau;&alpha;."' +
    '<P><FONT color=' + ALT_COLOR + '><B>La Hispana:</B> "El ping&uuml;ino Wenceslao hizo kil&oacute;metros bajo exhaustiva lluvia y fr&iacute;o, a&ntilde;oraba a su querido cachorro."</FONT>',

    // Unicode Examples II
    '<FONT color=' + HEAD_COLOR + '><B>Unicode Examples II</B></FONT>' +
    '<P>' +
    '<B>La Islanda:</B> "K&aelig;mi n&yacute; &ouml;xi h&eacute;r ykist &thorn;j&oacute;fum n&uacute; b&aelig;&eth;i v&iacute;l og &aacute;drepa."' +
    '<P><FONT color=' + ALT_COLOR + '><B>La Latva:</B> "Es varu &#x113;st stiklu, tas man nekait&#x113;."</FONT>' +
    '<P><B>La Nederlanda:</B> "We zaten met z&#x133;n drie&euml;n in een bootje op het &#x132;sselmeer."' +
    '<P><FONT color=' + ALT_COLOR + '><B>La Norvega:</B> "Jeg kan spise glas. Det gj&oslash;r meg ikke vondt."</FONT>' +
    '<P><B>La Pola:</B> "Pchn&#x105;&#x107; w t&#x119; &#x142;&oacute;d&#x17A; je&#x17C;a lub o&#x15B;m skrzy&#x144; fig."' +
    '<P><FONT color=' + ALT_COLOR + '><B>La Rumana:</B> "Pot s&#x103; m&#x103;n&acirc;nc sticl&#x103; &#x15F;a ea nu m&#x103; r&#x103;ne&#x15F;te."</FONT>' +
    '<P><B>La Rusa:</B> "&#x421;&#x44A;&#x435;&#x448;&#x44C; &#x435;&#x449;&#x451; &#x44D;&#x442;&#x438;&#x445; &#x436;&#x435; &#x43C;&#x44F;&#x433;&#x43A;&#x438;&#x445; &#x444;&#x440;&#x430;&#x43D;&#x446;&#x443;&#x437;&#x441;&#x43A;&#x438;&#x445; ' + '&#x431;&#x443;&#x43B;&#x43E;&#x43A;, &#x434;&#x430; &#x432;&#x44B;&#x43F;&#x435;&#x439; &#x447;&#x430;&#x44E;."' +
    '<P><FONT color=' + ALT_COLOR + '><B>La Sveda:</B> "Jag kan &auml;ta glas, det skadar mig inte."</FONT>' +
    '<P><B>La Turka:</B> "Cam yiyebilirim, bana zarar&#x131; dokunmaz."',

    // Formatting Text
    '<FONT color=' + HEAD_COLOR + '><B>Formatting Text</B></FONT>' +
    '<P>' +
    'We''ll start off with an example:' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>This text is <B>&lt;b&gt;</B>bold, and <B>&lt;i&gt;</B>italic' +
    '<B>&lt;/i&gt;</B>, and includes<B>&lt;/b&gt;</B> a <B>&lt;link&gt;</B>' +
    'link<B>&lt;/link&gt;</B>!</FONT>' +
    '<P>' +
    'Simply enter this text in the Caption property of the TDIHtmlLabel, ' +
    'just as you usually do with the TLabel component. The result looks ' +
    'something like this:' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>This text is <B>bold, and <I>italic</I>, and includes</B> a ' +
    '<A href=Next2>link</A>!</FONT>' +
    '<P>' +
    'For example, to start a section to be displayed as <B>bold text</B>, ' +
    'you''ll need to insert a "tag", in this case <B>&lt;b&gt;</B>. End the ' +
    'bold section with <B>&lt;/b&gt;</B>.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>For a full listing of supported tags, <A href=Next>go on to the next ' +
    'page!</A></FONT>',

    // Supported Tags
    '<FONT color=' + HEAD_COLOR + '><B>Supported Tags</B></FONT>' +
    '<P>' +
    'For Html tags, case does not make a difference throughout TDIHtmlLabel. ' +
    'You could use &lt;B&gt; just as well as &lt;b&gt;.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '><B>Basic text formatting:</B></FONT>' +
    '<P>' +
    '<B>&lt;B&gt;</B> &ndash; <B>Bold text style</B><BR>' +
    '<B>&lt;I&gt;</B> &ndash; <I>Italic text style</I><BR>' +
    '<B>&lt;S&gt;</B> &ndash; <S>strike-through text style</S><BR>' +
    '<B>&lt;U&gt;</B> &ndash; <U>Underlined text style</U><BR>' +
    '<B>&lt;FONT color=red&gt;</B> &ndash; <FONT color=red>Colored</FONT> <FONT color=green>text</FONT> <FONT color=blue>style</FONT>' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '><B>Line and paragraph breaks:</B></FONT>' +
    '<P>' +
    '<B>&lt;BR&gt;</B> &ndash; Line break (no end tag required)<BR>' +
    '<B>&lt;P&gt;</B> &ndash; Paragraph break (no end tag required)' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '><B>Special features:</B></FONT>' +
    '<P>' +
    '<B>&lt;LINK&gt;</B> &ndash; <A href=Next3>Hypertext links</A><BR>' +
    '<B>&lt;DYNAMIC&gt;</B> &ndash; Text whose contents change <A href=Next4>dynamically</A> (no end tag)',

    // Color Names I
    '<FONT color=' + HEAD_COLOR + '><B>Color Names A &ndash; L</B></FONT>' +
    COLOR_INTRO +
    '<P>' +
    '<B><FONT color=aliceblue>aliceblue</FONT> <FONT ' +
    'color=antiquewhite>antiquewhite</FONT> <FONT color=aqua>aqua</FONT> <FONT ' +
    'color=aquamarine>aquamarine</FONT> <FONT color=azure>azure</FONT> <FONT ' +
    'color=beige>beige</FONT> <FONT color=bisque>bisque</FONT> <FONT ' +
    'color=black>black</FONT> <FONT color=blanchedalmond>blanchedalmond</FONT> <FONT ' +
    'color=blue>blue</FONT> <FONT color=blueviolet>blueviolet</FONT> <FONT ' +
    'color=brown>brown</FONT> <FONT color=burlywood>burlywood</FONT> <FONT ' +
    'color=cadetblue>cadetblue</FONT> <FONT color=chartreuse>chartreuse</FONT> <FONT ' +
    'color=chocolate>chocolate</FONT> <FONT color=coral>coral</FONT> <FONT ' +
    'color=cornflowerblue>cornflowerblue</FONT> <FONT color=cornsilk>cornsilk</FONT> ' +
    '<FONT color=crimson>crimson</FONT> <FONT color=cyan>cyan</FONT> <FONT ' +
    'color=darkblue>darkblue</FONT> <FONT color=darkcyan>darkcyan</FONT> <FONT ' +
    'color=darkgoldenrod>darkgoldenrod</FONT> <FONT color=darkgray>darkgray</FONT> ' +
    '<FONT color=darkgreen>darkgreen</FONT> <FONT color=darkkhaki>darkkhaki</FONT> ' +
    '<FONT color=darkmagenta>darkmagenta</FONT> <FONT ' +
    'color=darkolivegreen>darkolivegreen</FONT> <FONT ' +
    'color=darkorange>darkorange</FONT> <FONT color=darkorchid>darkorchid</FONT> ' +
    '<FONT color=darkred>darkred</FONT> <FONT color=darksalmon>darksalmon</FONT> ' +
    '<FONT color=darkseagreen>darkseagreen</FONT> <FONT ' +
    'color=darkslateblue>darkslateblue</FONT> <FONT ' +
    'color=darkslategray>darkslategray</FONT> <FONT ' +
    'color=darkturquoise>darkturquoise</FONT> <FONT ' +
    'color=darkviolet>darkviolet</FONT> <FONT color=deeppink>deeppink</FONT> <FONT ' +
    'color=deepskyblue>deepskyblue</FONT> <FONT color=dimgray>dimgray</FONT> <FONT ' +
    'color=dodgerblue>dodgerblue</FONT> <FONT color=firebrick>firebrick</FONT> <FONT ' +
    'color=floralwhite>floralwhite</FONT> <FONT color=forestgreen>forestgreen</FONT> ' +
    '<FONT color=fuchsia>fuchsia</FONT> <FONT color=gainsboro>gainsboro</FONT> <FONT ' +
    'color=ghostwhite>ghostwhite</FONT> <FONT color=gold>gold</FONT> <FONT ' +
    'color=goldenrod>goldenrod</FONT> <FONT color=gray>gray</FONT> <FONT ' +
    'color=green>green</FONT> <FONT color=greenyellow>greenyellow</FONT> <FONT ' +
    'color=honeydew>honeydew</FONT> <FONT color=hotpink>hotpink</FONT> <FONT ' +
    'color=indianred>indianred</FONT> <FONT color=indigo>indigo</FONT> <FONT ' +
    'color=ivory>ivory</FONT> <FONT color=khaki>khaki</FONT> <FONT ' +
    'color=lavender>lavender</FONT> <FONT color=lavenderblush>lavenderblush</FONT> ' +
    '<FONT color=lawngreen>lawngreen</FONT> <FONT ' +
    'color=lemonchiffon>lemonchiffon</FONT> <FONT color=lightblue>lightblue</FONT> ' +
    '<FONT color=lightcoral>lightcoral</FONT> <FONT color=lightcyan>lightcyan</FONT> ' +
    '<FONT color=lightgoldenrodyellow>lightgoldenrodyellow</FONT> <FONT ' +
    'color=lightgreen>lightgreen</FONT> <FONT color=lightgrey>lightgrey</FONT> <FONT ' +
    'color=lightpink>lightpink</FONT> <FONT color=lightsalmon>lightsalmon</FONT> ' +
    '<FONT color=lightseagreen>lightseagreen</FONT> <FONT ' +
    'color=lightskyblue>lightskyblue</FONT> <FONT ' +
    'color=lightslategray>lightslategray</FONT></B>' +
    COLOR_OUTRO,

    // Color Names II
    '<FONT color=' + HEAD_COLOR + '><B>Color Names L &ndash; Y</B></FONT>' +
    COLOR_INTRO +
    '<P>' +
    '<B><FONT color=lightsteelblue>lightsteelblue</FONT> <FONT ' +
    'color=lightyellow>lightyellow</FONT> <FONT color=lime>lime</FONT> <FONT ' +
    'color=limegreen>limegreen</FONT> <FONT color=linen>linen</FONT> ' +
    '<FONT color=magenta>magenta</FONT> <FONT color=maroon>maroon</FONT> ' +
    '<FONT color=mediumaquamarine>mediumaquamarine</FONT> <FONT ' +
    'color=mediumblue>mediumblue</FONT> <FONT color=mediumorchid>mediumorchid</FONT> ' +
    '<FONT color=mediumpurple>mediumpurple</FONT> <FONT ' +
    'color=mediumseagreen>mediumseagreen</FONT> <FONT ' +
    'color=mediumslateblue>mediumslateblue</FONT> <FONT ' +
    'color=mediumspringgreen>mediumspringgreen</FONT> <FONT ' +
    'color=mediumturquoise>mediumturquoise</FONT> <FONT ' +
    'color=mediumvioletred>mediumvioletred</FONT> <FONT ' +
    'color=midnightblue>midnightblue</FONT> <FONT color=mintcream>mintcream</FONT> ' +
    '<FONT color=mistyrose>mistyrose</FONT> <FONT color=moccasin>moccasin</FONT>' +
    '<FONT color=navajowhite>navajowhite</FONT> <FONT color=navy>navy</FONT> ' +
    '<FONT color=oldlace>oldlace</FONT> <FONT color=olive>olive</FONT> <FONT ' +
    'color=olivedrab>olivedrab</FONT> <FONT color=orange>orange</FONT> <FONT ' +
    'color=orangered>orangered</FONT> <FONT color=orchid>orchid</FONT> <FONT ' +
    'color=palegoldenrod>palegoldenrod</FONT> <FONT color=palegreen>palegreen</FONT> ' +
    '<FONT color=paleturquoise>paleturquoise</FONT> <FONT ' +
    'color=palevioletred>palevioletred</FONT> <FONT ' +
    'color=papayawhip>papayawhip</FONT> <FONT color=peachpuff>peachpuff</FONT> <FONT ' +
    'color=peru>peru</FONT> <FONT color=pink>pink</FONT> <FONT color=plum>plum</FONT> ' +
    '<FONT color=powderblue>powderblue</FONT> <FONT color=purple>purple</FONT> <FONT ' +
    'color=red>red</FONT> <FONT color=rosybrown>rosybrown</FONT> <FONT ' +
    'color=royalblue>royalblue</FONT> <FONT color=saddlebrown>saddlebrown</FONT> ' +
    '<FONT color=salmon>salmon</FONT> <FONT color=sandybrown>sandybrown</FONT> <FONT ' +
    'color=seagreen>seagreen</FONT> <FONT color=seashell>seashell</FONT> <FONT ' +
    'color=sienna>sienna</FONT> <FONT color=silver>silver</FONT> <FONT ' +
    'color=skyblue>skyblue</FONT> <FONT color=slateblue>slateblue</FONT> <FONT ' +
    'color=slategray>slategray</FONT> <FONT color=snow>snow</FONT> <FONT ' +
    'color=springgreen>springgreen</FONT> <FONT color=steelblue>steelblue</FONT> ' +
    '<FONT color=tan>tan</FONT> <FONT color=teal>teal</FONT> <FONT ' +
    'color=thistle>thistle</FONT> <FONT color=tomato>tomato</FONT> <FONT ' +
    'color=turquoise>turquoise</FONT> <FONT color=violet>violet</FONT> <FONT ' +
    'color=wheat>wheat</FONT> <FONT color=white>white</FONT> <FONT ' +
    'color=whitesmoke>whitesmoke</FONT> <FONT color=yellow>yellow</FONT> <FONT ' +
    'color=yellowgreen>yellowgreen</FONT></B>' +
    COLOR_OUTRO,

    // Handling Links
    '<FONT color=' + HEAD_COLOR + '><B>Handling Links</B></FONT>' +
    '<P>' +
    'What happens when a user clicks a link? The <I>OnLinkClick</I> event ' +
    'handler fires, making it easy for you to perform any action you want. ' +
    'You may, for instance, open the user''s web browser, displaying a web ' +
    'page, or you can bring up a dialog window in your application, or ' +
    'something entirely different.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>The <I>LinkHref</I> parameter tells you which link the user ' +
    'clicked, while the <I>LinkText</I> tells you the contents of the ' +
    'link (with any tags removed).</FONT>' +
    '<P>' +
    'Click <A href=Show>here</A> to trigger the following Html link: ' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '><I>&lt;A&nbsp;href=Show>here&lt;/A></I></FONT>' +
    '<P>' +
    'It is implemented to display a messagebox with the <I>OnLinkClick</I> parameters. ' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>You can, however, use the <I>OnLinkClick</I> for other link implementations ' +
    'as demonstrated in this demo application.</FONT>',

    // Dynamic Tags
    '<FONT color=' + HEAD_COLOR + '><B>Dynamic Tags</B></FONT>' +
    '<P>' +
    '<I>Dynamic content</I> is used for content which may not be known when ' +
    'you design the form, or content that changes during the course of ' +
    'time, such as a label reporting memory usage. While you could simply ' +
    'assign a new string to the <I>Caption</I> property, you''d have to ' +
    'store the information both in the form file, and in the code itself ' +
    '(or only the latter). To add insult to injury, the entire string would ' +
    'have to be reparsed, negatively impacting performance. Also, this ' +
    'solution is awkward at best, and hard to maintain.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>Enter dynamic tags. Specify which content changes dynamically by ' +
    'replacing the text itself with <I>&lt;DYNAMIC&gt;</I>. You''ll need to ' +
    'handle the <I>OnInitDynamicTag</I> event to give these tags default ' +
    'values. At run-time, simply call <I>FMyLinkLabel.UpdateDynamicTag</I> ' +
    'to update the contents of the dynamic tag at will!</FONT>' +
    '<P>' +
    'Type into the edit box below to change the following line coded as ' +
    '<I>&lt;DYNAMIC id=Edit></I>.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '><DYNAMIC id=Edit></FONT>',

    // Play!
    '<FONT color=' + HEAD_COLOR + '><B>Play!</B></FONT>' +
    '<P>' +
    '<A href=Play>Click here</A> to open a separate window, where you can test ' +
    'the TDIHtmlLabel interactively! Feel free to edit the text in the edit ' +
    'box (or replace it completely), to see how TDIHtmlLabel renders your ' +
    'input. On the right, you''ll see a tree representation of the contents ' +
    'of the edit box.' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '><B>Note:</B> I believe that the text in the separate window is used in ' +
    'various desktop publishing products as placeholder text &ndash; this copy ' +
    'was found on the Internet. As I don''t speak Latin, I have no idea ' +
    'what it means, if anything.</FONT>',

    // Source Code
    '<FONT color=' + HEAD_COLOR + '><B>Source Code</B></FONT>' +
    '<P>' +
    'TDIHtmlLabel''s source code is clearly written and mostly easy ' +
    'to follow. Feel free to contribute!' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>TDIHtmlLabel consists primarily of the component itself, a parser ' +
    'which tries to make sense of the contents of the <I>Caption</I> ' +
    'property and returns a tree representation of this data, and a ' +
    'renderer, which renders the output to your screen.</FONT>' +
    '<P>' +
    'Please read the <A href=Next>full documentation</A> for pointers on ' +
    'features I''d like to see implemented in the future, and any bugs ' +
    'which I would love to see squashed. You''ll also find comments ' +
    'pertaining to areas where performance could be improved, and areas of ' +
    'the code that could be more modular. In short, if you''d like to hack ' +
    'the code, see this document for useful tips!',

    // Read More
    '<FONT color=' + HEAD_COLOR + '><B>Read More</B></FONT>' +
    '<P>' +
    'At this time, the documentation is maintained as a standard text file, ' +
    'although we plan to provide it either as XHTML/CSS or as a help file ' +
    'in the future. Look for it in the TDIHtmlLabel directory!' +
    '<P>' +
    '<FONT color=' + ALT_COLOR + '>Thanks for using TDIHtmlLabel!</FONT>' +
    '<P>' +
    '<I>Ralf Junker</I>');

  Lorem =
    '<B>Lorem ipsum dolor <I>sit</I> amet,</B> consectetuer adipiscing elit, ' +
    'sed diam nonummy nibh euismod <A>t<B>i<I>n</I>c</B>i<I>d</I>u<B>n</B>' +
    't <B>ut</B> laoreet</A> dolore magna aliquam erat volutpat. Ut wisi ' +
    'enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit ' +
    'lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum ' +
    '<B>iriure</B> dolor in hendrerit in vulputate velit esse molestie ' +
    'consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et ' +
    '<A>accumsan et iusto odio <I>dignissim qui <u>blandit praesent ' +
    'luptatum</u> zzril delenit augue duis dolore te feugait nulla facilisi. ' +
    'Lorem ipsum dolor</I> sit</A> amet, consectetuer adipiscing elit, ' +
    'sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam ' +
    'erat volutpat. Ut wisi enim ad <I>minim veniam, quis nostrud exerci ' +
    'tation ullamcorper suscipit lobortis nisl </I>ut aliquip ex ea commodo ' +
    'consequat.' +

    { Uncomment to test GB18030 Character Set}
    {
    '<P>' +
    '<META http-equiv=content-type content=charset=GB18030>' +
    'ѡȷĴ𰸡"  ' +
    '    ߹  ' +
    ' |||  ⼰˵  ѡȷĴ𰸡"' +
    }

    '<P>' +
    '<META http-equiv=content-type content=charset=Latin1>' +
    'Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse ' +
    'molestie consequat, vel <I>illum</I> dolore eu feugiat nulla facilisis ' +
    'at vero eros et accumsan et iusto odio dignissim qui blandit praesent ' +
    'luptatum zzril delenit <B>augue duis</B> dolore te feugait nulla ' +
    'facilisi. Nam liber tempor cum soluta nobis eleifend option congue ' +
    'nihil imperdiet doming <A>id quod mazim</A> placerat facer possim ' +
    'assum.' +
    '<P>' +
    'Lorem ipsum <I>dolor sit</I> amet, consectetuer adipiscing elit, sed diam ' +
    'nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat ' +
    'volutpat. Ut wisi enim <B>ad</B> minim veniam, quis nostrud exerci tation ' +
    'ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. ' +
    'Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse ' +
    'molestie consequat, vel <A>illum dolore <u>eu</u> feugiat nulla ' +
    'facilisis at vero eros et </A>accumsan et iusto odio dignissim qui ' +
    'blandit praesent luptatum zzril delenit augue duis <B>dolore te ' +
    'feugait</B> nulla facilisi. Lorem ipsum dolor sit amet, consectetuer ' +
    'adipiscing elit, sed diam nonummy nibh euismod tincidunt ut <A>' +
    'laoreet dolore</A> magna aliquam erat volutpat.' +
    '<P>' +
    '<B>Ut wisi enim</B> ad minim veniam, quis nostrud exerci <A>tation ' +
    'ullamcorper suscipit</A> lobortis nisl ut aliquip ex ea commodo ' +
    'consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate ' +
    'velit esse molestie consequat, vel <B>illum <I>dolore eu <u>feugiat ' +
    'nulla </u>facilisis at vero eros et accumsan et iusto</I> odio ' +
    'dignissim</B> qui blandit praesent luptatum zzril delenit augue duis ' +
    'dolore te feugait nulla facilisi. Lorem ipsum dolor sit amet, ' +
    'consectetuer adipiscing elit, <A>sed diam <I>nonummy </I></A>' +
    'nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.' +
    '<P>' +
    'Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper ' +
    'suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem ' +
    'vel eum iriure <B>dolor in</B> hendrerit <A>in vulputate <I>velit' +
    '</I></A> esse molestie consequat, vel illum dolore eu feugiat nulla ' +
    'facilisis at vero eros et accumsan et iusto odio dignissim <B>qui ' +
    'blandit</B> praesent luptatum zzril delenit augue duis dolore te ' +
    'feugait nulla facilisi. ' +
    '<P>' +
    'Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam ' +
    'nonummy nibh euismod <u>tincidunt</u> ut laoreet dolore magna aliquam ' +
    'erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ' +
    'ullamcorper <A>suscipit lobortis</A> nisl ut aliquip ex ea ' +
    'commodo consequat. Duis autem vel eum iriure dolor in hendrerit in ' +
    'vulputate velit esse molestie consequat, vel illum <I>dolore eu <B>' +
    'feugiat</B></I> nulla facilisis at.' +
    '<P>' +
    'Vero eros et accumsan <A>et iusto</A> odio dignissim qui blandit ' +
    'praesent luptatum zzril delenit augue duis dolore te feugait nulla ' +
    'facilisi. Lorem ipsum dolor sit <B>amet</B>, consectetuer adipiscing ' +
    'elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna ' +
    'aliquam erat volutpat. Ut wisi enim ad <I>minim veniam</I>, quis ' +
    'nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ' +
    'ea commodo consequat.' +
    '<P>' +
    '<B>Autem vel</B> eum iriure dolor in hendrerit in vulputate velit esse ' +
    'molestie consequat, <A>vel illum</A> dolore eu feugiat nulla ' +
    'facilisis at vero eros et accumsan et <I>iusto odio dignissim</I> qui ' +
    'blandit praesent luptatum zzril delenit augue <B>duis dolore</B> te ' +
    'feugait nulla facilisi.';

implementation

end.

